==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridRowEditEndedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridRowEditEndedEventArgsDescription } from "./GridRowEditEndedEventArgsDescription";
/**
 * @hidden
 */
var GridRowEditEndedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridRowEditEndedEventArgsDescriptionMetadata, _super);
    function GridRowEditEndedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridRowEditEndedEventArgsDescriptionMetadata.b = function (a) {
        if (GridRowEditEndedEventArgsDescriptionMetadata.a == null) {
            GridRowEditEndedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridRowEditEndedEventArgsDescriptionMetadata.c(GridRowEditEndedEventArgsDescriptionMetadata.a);
        }
        if (a.g(GridRowEditEndedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridRowEditEndedEventArgsDescriptionMetadata.a);
    };
    GridRowEditEndedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Row", "Number:int");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    GridRowEditEndedEventArgsDescriptionMetadata.d = function (a) {
        GridRowEditEndedEventArgsDescriptionMetadata.b(a);
        a.u("GridRowEditEndedEventArgs", function () { return new GridRowEditEndedEventArgsDescription(); });
        a.t("GridRowEditEndedEventArgs", GridRowEditEndedEventArgsDescriptionMetadata.a);
    };
    GridRowEditEndedEventArgsDescriptionMetadata.$t = markType(GridRowEditEndedEventArgsDescriptionMetadata, 'GridRowEditEndedEventArgsDescriptionMetadata');
    GridRowEditEndedEventArgsDescriptionMetadata.a = null;
    return GridRowEditEndedEventArgsDescriptionMetadata;
}(Base));
export { GridRowEditEndedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridRowEditEndedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridRowEditEndedEventArgsDescription } from "./GridRowEditEndedEventArgsDescription";
/**
 * @hidden
 */
var GridRowEditEndedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridRowEditEndedEventArgsDescriptionMetadata, _super);
    function GridRowEditEndedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridRowEditEndedEventArgsDescriptionMetadata.b = function (a) {
        if (GridRowEditEndedEventArgsDescriptionMetadata.a == null) {
            GridRowEditEndedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridRowEditEndedEventArgsDescriptionMetadata.c(GridRowEditEndedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridRowEditEndedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridRowEditEndedEventArgsDescriptionMetadata.a);
    };
    GridRowEditEndedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Row", "Number:int");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    GridRowEditEndedEventArgsDescriptionMetadata.d = function (a) {
        GridRowEditEndedEventArgsDescriptionMetadata.b(a);
        a.aa("GridRowEditEndedEventArgs", function () { return new GridRowEditEndedEventArgsDescription(); });
        a.z("GridRowEditEndedEventArgs", GridRowEditEndedEventArgsDescriptionMetadata.a);
    };
    GridRowEditEndedEventArgsDescriptionMetadata.$t = markType(GridRowEditEndedEventArgsDescriptionMetadata, 'GridRowEditEndedEventArgsDescriptionMetadata');
    GridRowEditEndedEventArgsDescriptionMetadata.a = null;
    return GridRowEditEndedEventArgsDescriptionMetadata;
}(Base));
export { GridRowEditEndedEventArgsDescriptionMetadata };
